function HF = figure_diff_bed(input_start,input_end,output,Ncolors,cmax)

if nargin==2
    output = [];
end
if nargin<=3 || isempty(Ncolors)
    Ncolors=5;
end
if nargin <= 4 || isempty(cmax)
    cmax = 100;
end

RWB = custom_colormap(Ncolors,[178 171 210]/255,[253 184 99]/255);

L_start = length(input_start.VI);
L_end = length(input_end.VI);

VI_start_tot = cell2mat(input_start.VI(1));
if L_start>=2
    for i=2:L_start
        VI_start_tot = cat(3,VI_start_tot,cell2mat(input_start.VI(i)));
    end
    VI_start_tot = nanmean(VI_start_tot,3);
end

VI_end_tot = cell2mat(input_end.VI(1));
if L_end>=2
    for i=2:L_end
        VI_end_tot = cat(3,VI_end_tot,cell2mat(input_end.VI(i)));
    end
    VI_end_tot = nanmean(VI_end_tot,3);
end

HF = makefigure(17,4);

diffVals = VI_end_tot-VI_start_tot;
diffVals(abs(diffVals)<cmax/(Ncolors+0.5)) = NaN;

hAxes1 = axes;
colormap(hAxes1,RWB);
h1 = pcolor(input_end.XI{1},input_end.YI{1},diffVals);
set(h1,'LineStyle','none');
set(hAxes1,'XDir','reverse','YDir','reverse','ticklabelInterpreter','latex');
xlabel('$x\ (\mathrm{mm})$','interpreter','latex');
ylabel('$y\ (\mathrm{mm})$','interpreter','latex');
ylim([0 2600]);
set(hAxes1,'Color','none')

h = colorbar;

ylabel(h,'$z - z_0 \ (\mathrm{mm})$','interpreter','latex');
set(h,'ticklabelinterpreter','latex');
caxis([-cmax cmax]);

%%% set minimal whitespace around figure
outerpos = hAxes1.OuterPosition;
ti = hAxes1.TightInset; 
left = outerpos(1) + ti(1);
bottom = outerpos(2) + ti(2);
ax_width = outerpos(3) - ti(1) - ti(3) - (ti(1)/2); % last term to make sure that label of colorbar is included within OuterPosition
ax_height = outerpos(4) - ti(2) - ti(4);
hAxes1.Position = [left bottom ax_width ax_height];
%%%

hAxesBack = axes('Outerposition',hAxes1.OuterPosition,'Position',hAxes1.Position);

colormap(hAxesBack,flipud(gray));
hBack = pcolor(input_end.XI{1},input_end.YI{1},VI_start_tot);
caxis([200 300]);
set(hBack,'FaceColor','interp','LineStyle','none');
set(hAxesBack,'XDir','reverse','YDir','reverse');
uistack(hAxesBack,'bottom')
axis(hAxesBack,'off')

linkaxes([hAxesBack,hAxes1]);

set(gcf,'CurrentAxes',hAxes1);

if ~isempty(output)
    printfigure([output '_rgb'],'raster','rgb');
    printfigure([output '_cmyk'],'raster','cmyk');
    savefig(HF,[output '.fig']);
end
