exp_list = {'A1','A2','B1','B2','C1','C2','D1','D2'};
exp_valid = [1 2 4 5 6]; % experiments leading to valid results (only for plotting purposes)
bedlevel_folder = '~/Documents/abstracts_papers/PAPER2_lab/experiments_LTD/Exp%s/laser_scanner/still/%s';
velocities_file = '~/Documents/abstracts_papers/PAPER2_lab/experiments_LTD/Exp%s/data_velocity_bedlevel.mat';
output_mu = '~/Documents/abstracts_papers/PAPER2_lab/experiments_LTD/figures/flow_contraction_20180816/flow_contraction';

xlims = [7985 8985];
zbed = 200; % bed leveled initially at 200mm
yADV = 590; % y-value of ADV-measurements in side channel, closest to LTD: 588mm, which is most closely approximated by 590 on the grid with dx=dy=5mm
u_lim = 0.02; % limit of u-velocities to take into account
z = [-40.5:-1:-69.5];

alpha_res = nan(size(exp_list));

for nn = 1:length(exp_list)
    
    experiment = exp_list{nn};
    
    switch experiment
        case 'A1'
            bedlevel_file = 'still_20180222.mat';
        case 'A2'
            bedlevel_file = 'still_20180302.mat';
        case 'AB1'
            bedlevel_file = 'dry_scan_Daan_03082018.mat';
        case 'AB2'
            bedlevel_file = 'Scan_bodem_still_daan_150302014.mat';
        case 'B1'
            bedlevel_file = 'final_scans_20180323.mat';
        case 'B2'
            bedlevel_file = 'Dryscan_daan_28032017.mat';
        case 'C1'
            bedlevel_file = 'dry_scan_07_06_2018.mat';
        case 'C2'
            bedlevel_file = 'still_20180615.mat';
        case 'D1'
            bedlevel_file = 'still_20180622.mat';
        case 'D2'
            bedlevel_file = 'still_20180702.mat';
    end
    
    load(sprintf(bedlevel_folder,experiment,bedlevel_file),'XI','YI','VI','h','z0')
    load(sprintf(velocities_file,experiment),'U2_filt2','V2_filt2','Zpos2','bed2');
    
%%% CALCULATE alpha (ANGLE BETWEEN MEAN VELOCITY VECTOR IN SIDE CHANNEL AND X-AXIS)    
        
    if strcmp(experiment(end),'1')
        Nlist = [17 18 23];
    else
        Nlist = [20 21 24 25];
        if strcmp(experiment,'B2')
            Nlist = Nlist(1:end-1);
        end
    end
    alpha = cell(length(Nlist),1);
    u = alpha;
    v = alpha;
    u_cut = alpha;
    
    for i=1:length(Nlist)
        u_cut = U2_filt2{Nlist(i)};
        v_cut = V2_filt2{Nlist(i)};
        u_cut(U2_filt2{Nlist(i)}<u_lim) = NaN;
        v_cut(U2_filt2{Nlist(i)}<u_lim) = NaN;
        
        z_lowest = Zpos2(i)-nanmean(bed2{i}*1000);
        zreal = Zpos2(i) + z;
        
        u{i} = nanmean(u_cut(:,zreal>=z_lowest),2);
        v{i} = nanmean(v_cut(:,zreal>=z_lowest),2);
        alpha{i} = acos(nanmean(u{i})/sqrt(nanmean(u{i})^2+nanmean(v{i})^2));
        
        if nanmean(v{i})>0
            alpha{i} = -alpha{i};
        end
        alpha{i} = single(alpha{i});
    end
    
    alpha_res(nn) = max(cell2mat(alpha));
    
%%% CALCULATE RELATIVE MEAN BED LEVEL HEIGHT 
    
    meanbed_rel(nn) = ( nanmean(VI{1}(YI{1}(:,1)==590,XI{1}(1,:)>=7985&XI{1}(1,:)<=8985)) - zbed ) / ( mean(h)-z0 - zbed ) ;
    
end

%%% TOTAL MEASURE mu FOR FLOW CONTRACTION

mu = alpha_res/(pi/2) .* meanbed_rel;

HF = makefigure;
hold on;
xlim([0 length(exp_list)+1]);
box on;
plot(xlim,[0 0],'--k');
plot(mu,'x');
plot(exp_valid,mu(exp_valid),'o','markersize',8);
ylabel('$\hat{\mu}$','interpreter','latex');
xlabel('experiment','interpreter','latex');
set(gca,'xticklabel',exp_list,'ticklabelinterpreter','latex','xticklabelrotation',45,'xtick',[1:length(exp_list)]);

if ~isempty(output_mu)
    printfigure([output_mu '_rgb'],'vector','rgb',HF);
    printfigure([output_mu '_cmyk'],'vector','cmyk',HF);
    savefig(HF,[output_mu '.fig']);
end
