function out = makefigure(varargin)
% MAKEFIGURE   creates figures.
%    HF=MAKEFIGURE creates figure with default size (width=8.5 cm height = 
%    6 cm) and returns handle of the figure
%    MAKEFIGURE(WIDTH) to customize width
%    MAKEFIGURE(WIDTH,HEIGHT) to customize both width and height
%
%    See also printfigure
%
%    Authors: Ryan Teuling and Bart Vermeulen
%    Last edit 25-06-2014


width = 8.5; % cm
height = 6; % cm

%narginchk(0,2)
%nargoutchk(0,1)
if nargin > 0, width = varargin{1}; end
if nargin > 1, height = varargin{2}; end

monpos=get(0,'monitorPositions');
dpi=get(0,'ScreenPixelsPerInch');
figpos=round([monpos(1,3)/2-width/2.54*dpi/2 monpos(1,4)/2-height/2.54*dpi/2 ...
        width/2.54*dpi height/2.54*dpi]);
    
hf=figure('position',figpos,'PaperUnits','Centimeters','PaperSize',...
    [width height],'paperposition',[0 0 width height],'resize','off','color',[1 1 1],'inverthardcopy','off');

% note: setting the background color to white and inverthardcopy to off
% prevents white colored lines, quivers, etc. to become black when printing
% and makes sure the background is printed white instead of gray

if nargout == 1, out = hf; end
